upoints.gpx

Package upoints :: Module gpx |
[hide private]
[frames] | no frames]

# Module gpx

gpx - Imports GPS eXchange format data files

Classes | [hide private]
| _GpxElem Abstract class for representing an element from GPX data files
| Waypoint Class for representing a waypoint element from GPX data files
| Waypoints Class for representing a group of Waypoint objects
| Trackpoint Class for representing a waypoint element from GPX data files
| Trackpoints Class for representing a group of Trackpoint objects

Functions | [hide private]
`function` |
create_elem(tag, attr=None, gpx_version=`'``1.1``'`, human_namespace=False) Create a partial `ET.Element` wrapper with namespace defined |

Variables | [hide private]
| GPX_VERSIONS = ``{``'``1.0``'``:` `'``http://www.topografix.com/GPX/1/0``'``,` `'``1``...`` Supported GPX namespace version to URI mapping
| DEF_GPX_VERSION = ``'``1.1``'`` Default GPX version to output

Function Details | [hide private]

### create_elem(tag, attr=None, gpx_version=`'``1.1``'`, human_namespace=False) |
Create a partial `ET.Element` wrapper with namespace defined Parameters: `tag` (`str`) - Tag name `attr` (`dict`) - Default attributes for tag `gpx_version` (`str`) - GPX version to use `human_namespace` (`bool`) - Whether to generate output using human readable namespace prefixes Returns: `function` `ET.Element` wrapper with predefined namespace

Variables Details | [hide private]

  ### GPX_VERSIONS Supported GPX namespace version to URI mapping Value:
      {'1.0': 'http://www.topografix.com/GPX/1/0',
       '1.1': 'http://www.topografix.com/GPX/1/1'}